@@ -47,6 +47,8 @@ from aws_lambda_fsm.constants import SYSTEM_CONTEXT
 from aws_lambda_fsm.constants import PAYLOAD
 from aws_lambda_fsm.constants import AWS
 from aws_lambda_fsm.constants import ERRORS
+from aws_lambda_fsm.constants import LEASE_DATA
+from aws_lambda_fsm.config import get_settings
 from aws_lambda_fsm.serialization import json_dumps_additional_kwargs
 from aws_lambda_fsm.serialization import json_loads_additional_kwargs
 
@@ -59,6 +61,7 @@ _local = Object()
 _lock = RLock()
 _local.machines = None
 
+settings = get_settings()
 logger = logging.getLogger(__name__)
 
 
@@ -286,13 +289,20 @@ class Context(dict):
             self.__system_context[SYSTEM_CONTEXT.CORRELATION_ID] = uuid.uuid4().hex
         return self.__system_context[SYSTEM_CONTEXT.CORRELATION_ID]
 
+    def _lookup_property(self, key, setting, default):
+        return self.__system_context.get(key, getattr(settings, setting, None)) or default
+
     @property
     def additional_delay_seconds(self):
-        return self.__system_context.get(SYSTEM_CONTEXT.ADDITIONAL_DELAY_SECONDS, 0)
+        return self._lookup_property(SYSTEM_CONTEXT.ADDITIONAL_DELAY_SECONDS, 'ADDITIONAL_DELAY_SECONDS', 0)
 
     @property
     def max_retries(self):
-        return self.__system_context[SYSTEM_CONTEXT.MAX_RETRIES]
+        return self._lookup_property(SYSTEM_CONTEXT.MAX_RETRIES, 'MAX_RETRIES', CONFIG.MAX_RETRIES)
+
+    @property
+    def lease_timeout(self):
+        return self._lookup_property(SYSTEM_CONTEXT.LEASE_TIMEOUT, 'LEASE_TIMEOUT', LEASE_DATA.LEASE_TIMEOUT)
 
     # Mutable properties
 
@@ -684,7 +694,7 @@ class Context(dict):
         try:
             # attempt to acquire the lease and execute the state transition
             fence_token = acquire_lease(self.correlation_id, self.steps, self.retries,
-                                        primary=self.lease_primary)
+                                        primary=self.lease_primary, timeout=self.lease_timeout)
 
             # 0 indicates system error, False indicates lease acquisition failure
             #
@@ -700,7 +710,7 @@ class Context(dict):
                 self._queue_error(ERRORS.CACHE, 'System error acquiring primary=%s lease.' % self.lease_primary)
                 self.lease_primary = not self.lease_primary
                 fence_token = acquire_lease(self.correlation_id, self.steps, self.retries,
-                                            primary=self.lease_primary)
+                                            primary=self.lease_primary, timeout=self.lease_timeout)
 
             if not fence_token:
                 # could not get the lease. something is going wrong
